---
tags:
  - prompt
author: agp
---

# Prompt

Consider documents located in the same directory as this file.

Read the 425 document carefully where all planning steps has been describes one by one.

The document contains tasks described in a Markdown format with bulleted ticks (tasks) to organize the specifications.

A tick can have children, which are also ticks, allowing for a hierarchical structure.

Ticks are organized in sequenctial phases.


---
